module SpreeThemeGenerator
  module Generators
    class ViewsGenerator < Rails::Generators::Base
      dir = "#{Gem.loaded_specs['spree_frontend'].full_gem_path}/app/views/spree"
      source_root File.expand_path(dir, __FILE__)

      class_option :views, aliases: "-v", type: :array, desc: "Select specific view directories to generate (address, checkout, content, home, layouts, order, payments, products, shared, store, taxons)"
      argument :scope, required: false, default: nil,
                       desc: "The scope to copy views to"

      def copy_views
        if options[:views]
          options[:views].each do |directory|
            view_directory directory.to_sym
          end
        else
          view_directory :address
          view_directory :checkout
          view_directory :home
          view_directory :layouts
          view_directory :orders
          view_directory :payments
          view_directory :products
          view_directory :shared
          view_directory :store
          view_directory :taxons
        end
      end

      protected

      def view_directory(name, _target_path = nil)
        directory name.to_s, _target_path || "#{target_path}/#{name}" do |content|
          if scope
            content.gsub "devise/shared/links", "#{scope}/shared/links"
          else
            content
          end
        end
      end

      def target_path
        @target_path ||= "app/views/spree"
      end
    end
  end
end
